@@ -193,10 +193,14 @@ static inline const char * name_of (int code) {
 
 /*---------------------------------------------------------------------------*\
 \*---------------------------------------------------------------------------*/
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,22)
+static void select_completion (struct urb * purb) {
+	struct usb_ctrlrequest	* req;
+#else
 static void select_completion (struct urb * purb, struct pt_regs * ptr) {
 	struct usb_ctrlrequest	* req;
-
 	UNUSED_ARG (ptr);
+#endif
 	assert (NULL != purb);
 	req = (struct usb_ctrlrequest *) purb->context;
 	LOG(
@@ -262,10 +266,14 @@ int select_config (
 
 /*---------------------------------------------------------------------------*\
 \*---------------------------------------------------------------------------*/
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,22)
+static void reset_completion (struct urb * purb) {
+	struct usb_ctrlrequest *	req;
+#else
 static void reset_completion (struct urb * purb, struct pt_regs * ptr) {
 	struct usb_ctrlrequest *	req;
-
 	UNUSED_ARG (ptr);
+#endif
 	assert (NULL != purb);
 	info (purb->status == 0);
 
@@ -345,7 +353,7 @@ static void copy_version (struct capi_ctr * ctrl) {
 	}
 	lib_strncpy (ctrl->serial, tmp, CAPI_SERIAL_LEN);
 	lib_memcpy (&ctrl->profile, card->string[6], sizeof (capi_profile));
-	strncpy (ctrl->manu, "AVM GmbH", CAPI_MANUFACTURER_LEN);
+	lib_strncpy (ctrl->manu, "AVM GmbH", CAPI_MANUFACTURER_LEN);
 	ctrl->version.majorversion = 2;
 	ctrl->version.minorversion = 0;
 	tmp = card->string[0];
@@ -1001,19 +1009,25 @@ static void issue_hard_error (card_p pdc, const char * msg, int arg) {
 
 /*---------------------------------------------------------------------------*\
 \*---------------------------------------------------------------------------*/ 
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,22)
+static void usb_write_completion (struct urb * purb) {
+#else
 static void usb_write_completion (struct urb * purb, struct pt_regs * ptr) {
-
-	UNUSED_ARG (purb);
 	UNUSED_ARG (ptr);
+#endif
+	UNUSED_ARG (purb);
 	tasklet_schedule (&tx_tasklet);
 } /* usb_write_completion */
 
 /*---------------------------------------------------------------------------*\
 \*---------------------------------------------------------------------------*/ 
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,22)
+static void usb_read_completion (struct urb * purb) {
+#else
 static void usb_read_completion (struct urb * purb, struct pt_regs * ptr) {
-
-	UNUSED_ARG (purb);
 	UNUSED_ARG (ptr);
+#endif
+	UNUSED_ARG (purb);
 	tasklet_schedule (&rx_tasklet);
 } /* usb_read_completion */
 
